@@ -121,18 +121,15 @@ void usage(void)
       xprintf(0, gettext(params[i].help));
   }
 
-
   fflush(stdout);
-  pavuk_do_at_exit();
-  _exit(PAVUK_EXIT_OK);
+  exit(PAVUK_EXIT_OK);
 }
 
 void usage_short(void)
 {
   xprintf(0, "%s %s %s %s\n", PACKAGE, VERSION, REVISION, HOSTTYPE);
   xprintf(0, gettext("Type \"%s --help\" for long help\n"), cfg.prg_path);
-  pavuk_do_at_exit();
-  _exit(PAVUK_EXIT_CFG_ERR);
+  exit(PAVUK_EXIT_CFG_ERR);
 }
 
 static void cfg_version_info(void)
@@ -243,7 +240,6 @@ static void cfg_version_info(void)
   xprintf(0, gettext(" - IPv6 support\n"));
 #endif
 
-  pavuk_do_at_exit();
   exit(PAVUK_EXIT_OK);
 }
 
@@ -338,7 +334,7 @@ static void cfg_set_to_default(cfg_param_t * cpar)
   switch (cpar->type)
   {
   case PARAM_NUM:
-    *((long *) cpar->val_adr) = (int) cpar->default_val;
+    *((long *) cpar->val_adr) = (long) cpar->default_val;
     break;
   case PARAM_PBOOL:
     *((bool_t *) cpar->val_adr) = (bool_t) (long) cpar->default_val;
@@ -347,8 +343,8 @@ static void cfg_set_to_default(cfg_param_t * cpar)
     *((bool_t *) cpar->val_adr) = (bool_t) (long) cpar->default_val;
     break;
   case PARAM_PORT_RANGE:
-    *((int *) cpar->val_adr) = (int) cpar->default_val;
-    *((int *) cpar->mval_adr) = (int) cpar->mdefault_val;
+    *((long *) cpar->val_adr) = (long) cpar->default_val;
+    *((long *) cpar->mval_adr) = (long) cpar->mdefault_val;
     break;
   case PARAM_PATH:
   case PARAM_STR:
@@ -372,7 +368,7 @@ static void cfg_set_to_default(cfg_param_t * cpar)
       *((long *) cpar->mval_adr) = (long) cpar->mdefault_val;
     break;
   case PARAM_AUTHSCH:
-    *((int *) cpar->val_adr) = (int) cpar->default_val;
+    *((long *) cpar->val_adr) = (long) cpar->default_val;
     break;
   case PARAM_MODE:
     *((long *) cpar->val_adr) = (long) cpar->default_val;
@@ -427,7 +423,7 @@ static void cfg_set_to_default(cfg_param_t * cpar)
 
       while(ptr)
       {
-        httphdr_free(ptr->data);
+        httphdr_free((httphdr *)ptr->data);
         ptr = dllist_remove_entry(ptr, ptr);
       }
     }
@@ -488,7 +484,7 @@ static void cfg_set_to_default(cfg_param_t * cpar)
       while(ptr)
         ptr = dllist_remove_entry(ptr, ptr);
       if(cpar->mval_adr)
-        *((bool_t *) cpar->mval_adr) = (bool_t) (int) cpar->mdefault_val;
+        *((bool_t *) cpar->mval_adr) = (bool_t) (long) cpar->mdefault_val;
     }
     break;
   case PARAM_FTPHS:
@@ -496,7 +492,7 @@ static void cfg_set_to_default(cfg_param_t * cpar)
       dllist *ptr = *((dllist **) cpar->val_adr);
       *((dllist **) cpar->val_adr) = NULL;
       for(; ptr; ptr = dllist_remove_entry(ptr, ptr))
-        ftp_handshake_info_free(ptr->data);
+        ftp_handshake_info_free((ftp_handshake_info *)ptr->data);
     }
     break;
   case PARAM_TAGPAT:
@@ -504,7 +500,7 @@ static void cfg_set_to_default(cfg_param_t * cpar)
       dllist *ptr = *((dllist **) cpar->val_adr);
       *((dllist **) cpar->val_adr) = NULL;
       for(; ptr; ptr = dllist_remove_entry(ptr, ptr))
-        tag_pattern_free(ptr->data);
+        tag_pattern_free((tag_pattern_t *)ptr->data);
     }
     break;
   }
@@ -542,8 +538,8 @@ void cfg_setup_default(void)
       *((bool_t *) params[i].val_adr) = (bool_t) (long) params[i].default_val;
       break;
     case PARAM_PORT_RANGE:
-      *((int *) params[i].val_adr) = (int) params[i].default_val;
-      *((int *) params[i].mval_adr) = (int) params[i].mdefault_val;
+      *((long *) params[i].val_adr) = (long) params[i].default_val;
+      *((long *) params[i].mval_adr) = (long) params[i].mdefault_val;
       break;
     case PARAM_PATH:
     case PARAM_STR:
@@ -622,7 +618,7 @@ void cfg_setup_default(void)
       *((dllist **) params[i].val_adr) = (dllist *) params[i].default_val;
       if(params[i].mval_adr)
         *((bool_t *) params[i].mval_adr) =
-          (bool_t) (int) params[i].mdefault_val;
+          (bool_t) (long) params[i].mdefault_val;
       break;
     case PARAM_FTPHS:
       *((dllist **) params[i].val_adr) = (dllist *) params[i].default_val;
@@ -636,7 +632,7 @@ void cfg_setup_default(void)
 
 int cfg_get_num_params(cfg_param_t * cpar)
 {
-  int num;
+  long num;
 
   static const struct
   {
@@ -678,7 +674,7 @@ int cfg_get_num_params(cfg_param_t * cpar)
   num = tab[cpar->type].num_params;
 
   if(cpar->type == PARAM_FUNC)
-    num = (int) cpar->default_val;
+    num = (long) cpar->default_val;
 
   return num;
 }
@@ -781,12 +777,12 @@ void cfg_setup_cmdln(int argc, char **argv)
         *((bool_t *) cpar->val_adr) = FALSE;
         break;
       case PARAM_PORT_RANGE:
-        if(sscanf(mopt.args[0], "%d:%d",
-            (int *) cpar->val_adr,
-            (int *) cpar->mval_adr) != 2
-          || *((int *) cpar->val_adr) <= 1023 ||
-          *((int *) cpar->mval_adr) > 65535 ||
-          *((int *) cpar->val_adr) >= *((int *) cpar->mval_adr))
+        if(sscanf(mopt.args[0], "%ld:%ld",
+            (long *) cpar->val_adr,
+            (long *) cpar->mval_adr) != 2
+          || *((long *) cpar->val_adr) <= 1023 ||
+          *((long *) cpar->mval_adr) > 65535 ||
+          *((long *) cpar->val_adr) >= *((long *) cpar->mval_adr))
         {
           xprintf(0, gettext("Invalid port range \"%s\"\n"), mopt.args[0]);
           usage_short();
@@ -882,7 +878,7 @@ void cfg_setup_cmdln(int argc, char **argv)
         *((time_t *) cpar->val_adr) = time_scn_cmd(mopt.args[0]);
         break;
       case PARAM_HTMLTAG:
-        htmltag_set_disabled(mopt.args[0], (int) cpar->default_val);
+        htmltag_set_disabled(mopt.args[0], (long) cpar->default_val);
         break;
       case PARAM_TWO_QSTR:
         cfg_set_to_default(cpar);
@@ -933,7 +929,7 @@ void cfg_setup_cmdln(int argc, char **argv)
           if(!lfnm)
             usage_short();
 
-          cfg.lfnames = dllist_append(cfg.lfnames, lfnm);
+          cfg.lfnames = dllist_append(cfg.lfnames, (dllist_t) lfnm);
         }
         break;
       case PARAM_RE:
@@ -949,7 +945,7 @@ void cfg_setup_cmdln(int argc, char **argv)
             usage_short();
           }
           *((dllist **) cpar->val_adr) =
-            dllist_append(*((dllist **) cpar->val_adr), ree);
+            dllist_append(*((dllist **) cpar->val_adr), (dllist_t) ree);
         }
 #endif
         break;
@@ -980,7 +976,7 @@ void cfg_setup_cmdln(int argc, char **argv)
             usage_short();
           }
           *((dllist **) cpar->val_adr) =
-            dllist_append(*((dllist **) cpar->val_adr), hr);
+            dllist_append(*((dllist **) cpar->val_adr), (dllist_t) hr);
         }
         break;
       case PARAM_DEBUGL:
@@ -1005,7 +1001,7 @@ void cfg_setup_cmdln(int argc, char **argv)
             usage_short();
           }
           *((dllist **) cpar->val_adr) =
-            dllist_append(*((dllist **) cpar->val_adr), ui);
+            dllist_append(*((dllist **) cpar->val_adr), (dllist_t) ui);
         }
         break;
       case PARAM_TRANSPARENT:
@@ -1032,7 +1028,7 @@ void cfg_setup_cmdln(int argc, char **argv)
             usage_short();
           else
             *((dllist **) cpar->val_adr) =
-              dllist_append(*((dllist **) cpar->val_adr), pr);
+              dllist_append(*((dllist **) cpar->val_adr), (dllist_t) pr);
         }
         else
         {
@@ -1060,9 +1056,8 @@ void cfg_setup_cmdln(int argc, char **argv)
         {
           js_transform_t *jt;
 
-          jt =
-            js_transform_new(mopt.args[0], mopt.args[1], mopt.args[2],
-            mopt.args[3], (int) cpar->mdefault_val);
+          jt = js_transform_new(mopt.args[0], mopt.args[1], mopt.args[2],
+          mopt.args[3], (long) cpar->mdefault_val);
 
           if(!jt)
           {
@@ -1072,7 +1067,7 @@ void cfg_setup_cmdln(int argc, char **argv)
           }
           else
           {
-            cfg.js_transform = dllist_append(cfg.js_transform, jt);
+            cfg.js_transform = dllist_append(cfg.js_transform, (dllist_t) jt);
           }
         }
 #endif
@@ -1090,7 +1085,7 @@ void cfg_setup_cmdln(int argc, char **argv)
           }
           cfg_set_to_default(cpar);
           if(cpar->mval_adr)
-            *((bool_t *) cpar->mval_adr) = (bool_t) (int) cpar->mdefault_val;
+            *((bool_t *) cpar->mval_adr) = (bool_t) (long) cpar->mdefault_val;
           *((dllist **) cpar->val_adr) = ptr;
         }
         break;
@@ -1108,19 +1103,18 @@ void cfg_setup_cmdln(int argc, char **argv)
             usage_short();
           }
           *((dllist **) cpar->val_adr) =
-            dllist_append(*((dllist **) cpar->val_adr), fhi);
+            dllist_append(*((dllist **) cpar->val_adr), (dllist_t) fhi);
         }
         break;
       case PARAM_TAGPAT:
         {
           tag_pattern_t *tp;
-          tp = tag_pattern_new(
-            (int) cpar->mdefault_val,
+          tp = tag_pattern_new((long) cpar->mdefault_val,
             mopt.args[0], mopt.args[1], mopt.args[2]);
           if(!tp)
             usage_short();
           *((dllist **) cpar->val_adr) =
-            dllist_append(*((dllist **) cpar->val_adr), tp);
+            dllist_append(*((dllist **) cpar->val_adr), (dllist_t) tp);
         }
         break;
       }
@@ -1130,7 +1124,7 @@ void cfg_setup_cmdln(int argc, char **argv)
     {
       url_info *ui;
       ui = url_info_new(mopt.args[0]);
-      cfg.request = dllist_append(cfg.request, ui);
+      cfg.request = dllist_append(cfg.request, (dllist_t) ui);
       cfg.total_cnt++;
     }
   }
@@ -1220,12 +1214,12 @@ static int cfg_load_fd(bufio * fd)
           }
           break;
         case PARAM_PORT_RANGE:
-          if(sscanf(lns, "%d:%d",
-              (int *) params[i].val_adr,
-              (int *) params[i].mval_adr) != 2
-            || *((int *) params[i].val_adr) <= 1023 ||
-            *((int *) params[i].mval_adr) > 65535 ||
-            *((int *) params[i].val_adr) >= *((int *) params[i].mval_adr))
+          if(sscanf(lns, "%ld:%ld",
+              (long *) params[i].val_adr,
+              (long *) params[i].mval_adr) != 2
+            || *((long *) params[i].val_adr) <= 1023 ||
+            *((long *) params[i].mval_adr) > 65535 ||
+            *((long *) params[i].val_adr) >= *((long *) params[i].mval_adr))
           {
             xprintf(0, gettext("Invalid port range \"%s\"\n"), lns);
             rv = 1;
@@ -1313,7 +1307,7 @@ static int cfg_load_fd(bufio * fd)
           }
           break;
         case PARAM_HTMLTAG:
-          htmltag_set_disabled(lns, (int) params[i].default_val);
+          htmltag_set_disabled(lns, (long) params[i].default_val);
           break;
         case PARAM_TWO_QSTR:
           cfg_set_to_default(&params[i]);
@@ -1382,7 +1376,7 @@ static int cfg_load_fd(bufio * fd)
             {
               lfnm = lfname_new(t, ps2, ps3);
               if(lfnm)
-                cfg.lfnames = dllist_append(cfg.lfnames, lfnm);
+                cfg.lfnames = dllist_append(cfg.lfnames, (dllist_t) lfnm);
               else
                 rv = 1;
             }
@@ -1403,7 +1397,7 @@ static int cfg_load_fd(bufio * fd)
             }
             else
               *(dllist **) params[i].val_adr =
-                dllist_append(*((dllist **) params[i].val_adr), ree);
+                dllist_append(*((dllist **) params[i].val_adr), (dllist_t) ree);
           }
 #endif
           break;
@@ -1443,7 +1437,7 @@ static int cfg_load_fd(bufio * fd)
             }
             else
               *((dllist **) params[i].val_adr) =
-                dllist_append(*((dllist **) params[i].val_adr), hr);
+                dllist_append(*((dllist **) params[i].val_adr), (dllist_t) hr);
           }
           break;
         case PARAM_DEBUGL:
@@ -1468,7 +1462,7 @@ static int cfg_load_fd(bufio * fd)
             }
             else
               *((dllist **) params[i].val_adr) =
-                dllist_append(*((dllist **) params[i].val_adr), ui);
+                dllist_append(*((dllist **) params[i].val_adr), (dllist_t) ui);
           }
           break;
         case PARAM_TRANSPARENT:
@@ -1488,7 +1482,7 @@ static int cfg_load_fd(bufio * fd)
 
             if(pr)
               *((dllist **) params[i].val_adr) =
-                dllist_append(*((dllist **) params[i].val_adr), pr);
+                dllist_append(*((dllist **) params[i].val_adr), (dllist_t) pr);
             else
               rv = 1;
           }
@@ -1505,9 +1499,8 @@ static int cfg_load_fd(bufio * fd)
 
             js_transform_t *jt;
 
-            jt =
-              js_transform_new(ps1, ps2, ps3, ps4,
-              (int) params[i].mdefault_val);
+            jt = js_transform_new(ps1, ps2, ps3, ps4,
+            (long) params[i].mdefault_val);
 
             if(!jt)
             {
@@ -1517,7 +1510,7 @@ static int cfg_load_fd(bufio * fd)
               rv = 1;
             }
             else
-              cfg.js_transform = dllist_append(cfg.js_transform, jt);
+              cfg.js_transform = dllist_append(cfg.js_transform, (dllist_t) jt);
             _free(ps1);
             _free(ps2);
             _free(ps3);
@@ -1529,7 +1522,7 @@ static int cfg_load_fd(bufio * fd)
           cfg_set_to_default(&params[i]);
           if(params[i].mval_adr)
             *((bool_t *) params[i].mval_adr) =
-              (bool_t) (int) params[i].mdefault_val;
+              (bool_t) (long) params[i].mdefault_val;
           if(*lns)
             *((dllist **) params[i].val_adr) = tl_numlist_split(lns, ",");
           if(*lns && !*((dllist **) params[i].val_adr))
@@ -1555,7 +1548,7 @@ static int cfg_load_fd(bufio * fd)
               rv = 1;
             }
             *((dllist **) params[i].val_adr) =
-              dllist_append(*((dllist **) params[i].val_adr), fhi);
+              dllist_append(*((dllist **) params[i].val_adr), (dllist_t) fhi);
             _free(ps1);
             _free(ps2);
           }
@@ -1568,12 +1561,14 @@ static int cfg_load_fd(bufio * fd)
             tag_pattern_t *tp = NULL;
 
             if(ps1 && ps2 && ps3)
-              tp =
-                tag_pattern_new((int) params[i].mdefault_val, ps1, ps2, ps3);
+	    {
+              tp = tag_pattern_new((long) params[i].mdefault_val,
+	      ps1, ps2, ps3);
+            }
             if(!tp)
               rv = 1;
             *((dllist **) params[i].val_adr) =
-              dllist_append(*((dllist **) params[i].val_adr), tp);
+              dllist_append(*((dllist **) params[i].val_adr), (dllist_t) tp);
             _free(ps1);
             _free(ps2);
             _free(ps3);
@@ -1594,7 +1589,7 @@ static int cfg_load_fd(bufio * fd)
         continue;
 
       ui = url_info_new(lns);
-      cfg.request = dllist_append(cfg.request, ui);
+      cfg.request = dllist_append(cfg.request, (dllist_t) ui);
       cfg.total_cnt++;
     }
     else if(!found)
@@ -1703,8 +1698,8 @@ static int cfg_dump_fd(int fd)
     switch (params[i].type)
     {
     case PARAM_NUM:
-      snprintf(pom, sizeof(pom), "%s %d\n", params[i].par_entry,
-        *((int *) params[i].val_adr));
+      snprintf(pom, sizeof(pom), "%s %ld\n", params[i].par_entry,
+        *((long *) params[i].val_adr));
       write(fd, pom, strlen(pom));
       break;
     case PARAM_NBOOL:
@@ -1716,10 +1711,10 @@ static int cfg_dump_fd(int fd)
       write(fd, pom, strlen(pom));
       break;
     case PARAM_PORT_RANGE:
-      if(*((int *) params[i].val_adr) >= 0)
+      if(*((long *) params[i].val_adr) >= 0)
       {
-        snprintf(pom, sizeof(pom), "%s %d:%d\n", params[i].par_entry,
-          *((int *) params[i].val_adr), *((int *) params[i].mval_adr));
+        snprintf(pom, sizeof(pom), "%s %ld:%ld\n", params[i].par_entry,
+          *((long *) params[i].val_adr), *((long *) params[i].mval_adr));
         write(fd, pom, strlen(pom));
       }
       break;
@@ -1765,7 +1760,7 @@ static int cfg_dump_fd(int fd)
       break;
     case PARAM_AUTHSCH:
       snprintf(pom, sizeof(pom), "%s %s\n", params[i].par_entry,
-        http_auths[*((int *) params[i].val_adr)].name);
+        http_auths[*((long *) params[i].val_adr)].name);
       write(fd, pom, strlen(pom));
       break;
     case PARAM_MODE:
@@ -1842,7 +1837,7 @@ static int cfg_dump_fd(int fd)
         dllist *pdl = cfg.lfnames;
         while(pdl)
         {
-          lfname *lfnm = pdl->data;
+          lfname *lfnm = (lfname *) pdl->data;
           char *p1, *p2;
 
           p1 = escape_str(lfnm->matchstr, "\\\"");
@@ -1865,7 +1860,7 @@ static int cfg_dump_fd(int fd)
         dllist *ptr = *((dllist **) params[i].val_adr);
         while(ptr)
         {
-          re_entry *ree = ptr->data;
+          re_entry *ree = (re_entry *) ptr->data;
 
           snprintf(pom, sizeof(pom), "%s %s\n", params[i].par_entry,
             ree->pattern);
@@ -1891,7 +1886,7 @@ static int cfg_dump_fd(int fd)
         dllist *ptr = *((dllist **) params[i].val_adr);
         while(ptr)
         {
-          httphdr *hr = ptr->data;
+          httphdr *hr = (httphdr *) ptr->data;
 
           snprintf(pom, sizeof(pom), "%s %s%s %s\n", params[i].par_entry,
             hr->all ? "+" : "", hr->name, hr->val);
@@ -1916,7 +1911,7 @@ static int cfg_dump_fd(int fd)
         dllist *ptr = *((dllist **) params[i].val_adr);
         while(ptr)
         {
-          url_info *ui = ptr->data;
+          url_info *ui = (url_info *) ptr->data;
 
           if(ui->type != URLI_NORMAL || ui->localname)
           {
@@ -1966,7 +1961,7 @@ static int cfg_dump_fd(int fd)
           js_transform_t *jt = (js_transform_t *) ptr->data;
           char *p[4];
 
-          if(jt->type != (int) params[i].mdefault_val)
+          if(jt->type != (long) params[i].mdefault_val)
             continue;
 
           p[0] = escape_str(jt->re->pattern, "\\\"");
@@ -1988,19 +1983,19 @@ static int cfg_dump_fd(int fd)
     case PARAM_NUMLIST:
       if(!params[i].mval_adr || (params[i].mval_adr &&
           (*((bool_t *) params[i].mval_adr) ==
-            (bool_t) (int) params[i].mdefault_val)))
+            (bool_t) (long) params[i].mdefault_val)))
       {
         dllist *ptr = *((dllist **) params[i].val_adr);
         if(ptr)
         {
-          snprintf(pom, sizeof(pom), "%s %d", params[i].par_entry,
-            (int) ptr->data);
+          snprintf(pom, sizeof(pom), "%s %ld", params[i].par_entry,
+            (long) ptr->data);
           write(fd, pom, strlen(pom));
 
           j = 1;
           for(; ptr; ptr = ptr->next)
           {
-            snprintf(pom, sizeof(pom), ",%d", (int) ptr->data);
+            snprintf(pom, sizeof(pom), ",%ld", (long) ptr->data);
             write(fd, pom, strlen(pom));
           }
           write(fd, "\n", 1);
@@ -2013,7 +2008,7 @@ static int cfg_dump_fd(int fd)
         for(ptr = *((dllist **) params[i].val_adr); ptr; ptr = ptr->next)
         {
           char *p, *p2;
-          ftp_handshake_info *fhi = ptr->data;
+          ftp_handshake_info *fhi = (ftp_handshake_info *)ptr->data;
 
           p = ftp_handshake_info_data_dump(fhi);
           p2 = escape_str(p, "\\\"");
@@ -2038,7 +2033,7 @@ static int cfg_dump_fd(int fd)
         for(ptr = *((dllist **) params[i].val_adr); ptr; ptr = ptr->next)
         {
           char *t, *a, *u;
-          tag_pattern_t *tp = ptr->data;
+          tag_pattern_t *tp = (tag_pattern_t *) ptr->data;
 
           t = escape_str(tp->tag, "\\\"");
           a = escape_str(tp->attrib, "\\\"");
@@ -2184,8 +2179,8 @@ int cfg_dump_cmd_fd(int fd)
     switch (params[i].type)
     {
     case PARAM_NUM:
-      snprintf(pom, sizeof(pom), " -%s=%d ", params[i].long_cmd,
-        *((int *) params[i].val_adr));
+      snprintf(pom, sizeof(pom), " -%s=%ld ", params[i].long_cmd,
+        *((long *) params[i].val_adr));
       write(fd, pom, strlen(pom));
       break;
     case PARAM_NBOOL:
@@ -2205,10 +2200,10 @@ int cfg_dump_cmd_fd(int fd)
       }
       break;
     case PARAM_PORT_RANGE:
-      if(*((int *) params[i].val_adr) >= 0)
+      if(*((long *) params[i].val_adr) >= 0)
       {
-        snprintf(pom, sizeof(pom), " -%s=%d:%d ", params[i].long_cmd,
-          *((int *) params[i].val_adr), *((int *) params[i].mval_adr));
+        snprintf(pom, sizeof(pom), " -%s=%ld:%ld ", params[i].long_cmd,
+          *((long *) params[i].val_adr), *((long *) params[i].mval_adr));
         write(fd, pom, strlen(pom));
       }
       break;
@@ -2254,7 +2249,7 @@ int cfg_dump_cmd_fd(int fd)
       break;
     case PARAM_AUTHSCH:
       snprintf(pom, sizeof(pom), " -%s %s ", params[i].long_cmd,
-        http_auths[*((int *) params[i].val_adr)].name);
+        http_auths[*((long *) params[i].val_adr)].name);
       write(fd, pom, strlen(pom));
       break;
     case PARAM_MODE:
@@ -2326,7 +2321,7 @@ int cfg_dump_cmd_fd(int fd)
         dllist *pdl = cfg.lfnames;
         while(pdl)
         {
-          lfname *lfnm = pdl->data;
+          lfname *lfnm = (lfname *)pdl->data;
 
           snprintf(pom, sizeof(pom), " -%s \'%s\' \'%s\' \'%s\' ",
             params[i].long_cmd, (lfnm->type == LFNAME_FNMATCH) ? "F" : "R",
@@ -2343,7 +2338,7 @@ int cfg_dump_cmd_fd(int fd)
         dllist *ptr = *((dllist **) params[i].val_adr);
         while(ptr)
         {
-          re_entry *ree = ptr->data;
+          re_entry *ree = (re_entry *)ptr->data;
 
           snprintf(pom, sizeof(pom), " -%s \'%s\' ", params[i].long_cmd,
             ree->pattern);
@@ -2369,7 +2364,7 @@ int cfg_dump_cmd_fd(int fd)
         dllist *ptr = *((dllist **) params[i].val_adr);
         while(ptr)
         {
-          httphdr *hr = ptr->data;
+          httphdr *hr = (httphdr *) ptr->data;
 
           snprintf(pom, sizeof(pom), " -%s \"%s%s %s\" ", params[i].long_cmd,
             hr->all ? "+" : "", hr->name, hr->val);
@@ -2395,7 +2390,7 @@ int cfg_dump_cmd_fd(int fd)
         dllist *ptr = *((dllist **) params[i].val_adr);
         while(ptr)
         {
-          url_info *ui = ptr->data;
+          url_info *ui = (url_info *) ptr->data;
 
           if(ui->type != URLI_NORMAL || ui->localname)
           {
@@ -2440,7 +2435,7 @@ int cfg_dump_cmd_fd(int fd)
         for(ptr = cfg.js_transform; ptr; ptr = ptr->next)
         {
           js_transform_t *jt = (js_transform_t *) ptr->data;
-          if(jt->type != (int) params[i].mdefault_val)
+          if(jt->type != (long) params[i].mdefault_val)
             continue;
 
           snprintf(pom, sizeof(pom), " -%s \'%s\' \'%s\' \'%s\' \'%s\' ",
@@ -2454,19 +2449,19 @@ int cfg_dump_cmd_fd(int fd)
     case PARAM_NUMLIST:
       if(!params[i].mval_adr || (params[i].mval_adr &&
           (*((bool_t *) params[i].mval_adr) ==
-            (bool_t) (int) params[i].mdefault_val)))
+            (bool_t) (long) params[i].mdefault_val)))
       {
         dllist *ptr = *((dllist **) params[i].val_adr);
         if(ptr)
         {
-          snprintf(pom, sizeof(pom), "-%s %d", params[i].long_cmd,
-            (int) ptr->data);
+          snprintf(pom, sizeof(pom), "-%s %ld", params[i].long_cmd,
+            (long) ptr->data);
           write(fd, pom, strlen(pom));
 
           j = 1;
           for(; ptr; ptr = ptr->next)
           {
-            snprintf(pom, sizeof(pom), ",%d", (int) ptr->data);
+            snprintf(pom, sizeof(pom), ",%ld", (long) ptr->data);
             write(fd, pom, strlen(pom));
           }
           write(fd, " ", 1);
@@ -2479,7 +2474,7 @@ int cfg_dump_cmd_fd(int fd)
         for(ptr = *((dllist **) params[i].val_adr); ptr; ptr = ptr->next)
         {
           char *p;
-          ftp_handshake_info *fhi = ptr->data;
+          ftp_handshake_info *fhi = (ftp_handshake_info *) ptr->data;
 
           p = ftp_handshake_info_data_dump(fhi);
 
@@ -2500,7 +2495,7 @@ int cfg_dump_cmd_fd(int fd)
         dllist *ptr;
         for(ptr = *((dllist **) params[i].val_adr); ptr; ptr = ptr->next)
         {
-          tag_pattern_t *tp = ptr->data;
+          tag_pattern_t *tp = (tag_pattern_t *) ptr->data;
 
           snprintf(pom, sizeof(pom),
             "-%s \"%s\" \"%s\" \"%s\" ",
