@@ -8,6 +8,7 @@
 #define _config_h_
 
 #include "../ac-config.h"
+typedef DLLISTTYPE dllist_t;
 
 #define NeedFunctionPrototypes 1
 
@@ -152,22 +153,22 @@ typedef struct
   char *post_cmd;               /*** command for post downloading processing of files ***/
   char *stats_file;             /*** status file ***/
 
-  int dumpfd;                   /*** number of filedescriptor for dumping documents ***/
-  int dump_urlfd;               /*** number of filedescriptor for dumping all URLs ***/
-  int hash_size;                /*** hash tables size ***/
-  int trans_quota;              /*** transfer quota ***/
-  int file_quota;               /*** file size quota ***/
-  int fs_quota;                 /*** filesystem quota ***/
-  int bufsize;                  /*** size of read buffer ***/
-  int base_level;               /*** base tree level from which is built local file tree ***/
-  int nretry;                   /*** number of retries on error ***/
-  int nreget;                   /*** number of regets ***/
-  int nredir;                   /*** max number of redirections ***/
-  int ddays;                    /*** delay in days for document reload ***/
-  int rollback;                 /*** size to go back when reget-ing ***/
-  int sleep;                    /*** sleeptime between transfers ***/
-  int cookies_max;              /*** maximal number of cookies ***/
-  int reschedh;                 /*** number of hours for rescheduling ***/
+  long dumpfd;                  /*** number of filedescriptor for dumping documents ***/
+  long dump_urlfd;              /*** number of filedescriptor for dumping all URLs ***/
+  long hash_size;               /*** hash tables size ***/
+  long trans_quota;             /*** transfer quota ***/
+  long file_quota;              /*** file size quota ***/
+  long fs_quota;                /*** filesystem quota ***/
+  long bufsize;                 /*** size of read buffer ***/
+  long base_level;              /*** base tree level from which is built local file tree ***/
+  long nretry;                  /*** number of retries on error ***/
+  long nreget;                  /*** number of regets ***/
+  long nredir;                  /*** max number of redirections ***/
+  long ddays;                   /*** delay in days for document reload ***/
+  long rollback;                /*** size to go back when reget-ing ***/
+  long sleep;                   /*** sleeptime between transfers ***/
+  long cookies_max;             /*** maximal number of cookies ***/
+  long reschedh;                /*** number of hours for rescheduling ***/
   double max_time;              /*** maximal time for run ***/
   pavuk_mode mode;              /*** working mode ***/
   struct tm *time;              /*** when to schedule execution time ***/
@@ -179,20 +180,20 @@ typedef struct
   char *ftp_proxy_user;         /*** username for access to FTP proxy ***/
   char *http_proxy_pass;        /*** password for access to HTTP proxy ***/
   char *http_proxy_user;        /*** username for access to HTTP proxy ***/
-  int proxy_auth_scheme;        /*** authorization scheme for proxy ***/
+  long proxy_auth_scheme;       /*** authorization scheme for proxy ***/
   char *ftp_proxy;              /*** FTP proxy server ***/
-  int ftp_proxy_port;
+  long ftp_proxy_port;
   bool_t ftp_via_http;          /*** gatewaying FTP through HTTP proxy ***/
   bool_t ftp_dirtyp;            /*** dirty FTP proxying via CONNECT request to HTTP proxy ***/
-  int active_ftp_min_port;      /*** minimum port for active ftp ***/
-  int active_ftp_max_port;      /*** minimum port for active ftp ***/
+  long active_ftp_min_port;     /*** minimum port for active ftp ***/
+  long active_ftp_max_port;     /*** minimum port for active ftp ***/
 
   char *gopher_proxy;           /*** Gopher proxy ***/
-  int gopher_proxy_port;
+  long gopher_proxy_port;
   bool_t gopher_via_http;       /*** gatewaying Gopher trough HTTP proxy ***/
   char *name_auth;              /*** meno pouzivatela pri HTTP autentifikacii ***/
   char *passwd_auth;            /*** password for HTTP authorization ***/
-  int auth_scheme;              /*** authorization scheme 1- user, 2- Basic, 3- Digest ***/
+  long auth_scheme;              /*** authorization scheme 1- user, 2- Basic, 3- Digest ***/
 
   bool_t rsleep;                /*** randomize sleep period up to -sleep ***/
   bool_t hack_add_index;        /*** add also directories of all files to queue ***/
@@ -289,7 +290,7 @@ typedef struct
   char *moz_cache_dir;          /*** directory for Mozilla cache ***/
 
 #ifdef HAVE_MT
-  int nthr;                     /*** configured number of running threads ***/
+  long nthr;                    /*** configured number of running threads ***/
   bool_t immessages;            /*** print messages immediatly when produced not just when it is safe ***/
 #endif
 
@@ -315,13 +316,13 @@ typedef struct
 
 #ifdef DEBUG
   bool_t debug;                 /*** debug mode on/off ***/
-  int debug_level;              /*** debug level ***/
+  long debug_level;             /*** debug level ***/
 #endif
 
 #ifdef USE_SSL
-  int ssl_version;              /*** ssl2/ssl3/ssl23/tls1 version of ssl_client_method() ***/
+  long ssl_version;             /*** ssl2/ssl3/ssl23/tls1 version of ssl_client_method() ***/
   char *ssl_proxy;              /*** SSL tuneling proxy ***/
-  int ssl_proxy_port;
+  long ssl_proxy_port;
   char *ssl_cipher_list;
   char *ssl_cert_passwd;
   bool_t unique_sslid;          /*** use unique SSL IDs with each SSL connection ***/
@@ -345,7 +346,7 @@ typedef struct
 
 #ifdef I_FACE
   char *fontname;               /*** default font used in interface ***/
-  int xlogsize;                 /*** max number of lines in LOG widget ***/
+  long xlogsize;                /*** max number of lines in LOG widget ***/
   bool_t log_autoscroll;        /*** autoscroll of log window ***/
   bool_t run_iface;             /*** if immediately run download after start of pavuk in GUI interface ***/
   bool_t use_prefs;             /*** store & load prefernces from ~/.pavuk_prefs file ***/
@@ -382,12 +383,12 @@ typedef struct
   long trans_size;              /*** transfered size in session ***/
   char *path_to_home;
   char *local_host;             /*** hostname of local machine ***/
-  int fail_cnt;                 /*** counter for failed transfers ---> return code of pavuk ***/
+  long fail_cnt;                /*** counter for failed transfers ---> return code of pavuk ***/
   char *prg_path;               /*** path to pavuk executable == argv[0] ***/
   char *install_path;           /*** pavuk install path especialy used in win32 version ***/
-  int total_cnt;                /*** total number of URLs in queue  ***/
-  int process_cnt;              /*** number of already processed documents ***/
-  int reject_cnt;               /*** number of rejected URLs ***/
+  long total_cnt;               /*** total number of URLs in queue  ***/
+  long process_cnt;             /*** number of already processed documents ***/
+  long reject_cnt;              /*** number of rejected URLs ***/
   pavuk_mode prev_mode;         /*** previous active mode ***/
   bool_t mode_started;          /*** mode startup finisched ***/
   bool_t rbreak;                /*** immediately stop transfer ***/
@@ -413,7 +414,7 @@ typedef struct
   mt_semaphore urlstack_sem;
   pthread_t mainthread;
   pthread_t *allthreads;
-  int allthreadsnr;
+  long allthreadsnr;
 #endif
 
 #ifdef I_FACE
