@@ -124,8 +124,11 @@ char *form_get_text(int num, char *html_text, int html_len, int *form_len)
   return stack;
 }
 
-int form_field_compare(form_field * ff1, form_field * ff2)
+int form_field_compare(dllist_t dl1, dllist_t dl2)
 {
+  form_field * ff1 = (form_field *)dl1;
+  form_field * ff2 = (form_field *)dl2;
+
   if(strcmp(ff1->name, ff2->name))
     return FALSE;
 
@@ -135,8 +138,11 @@ int form_field_compare(form_field * ff1, form_field * ff2)
   return TRUE;
 }
 
-int form_field_compare_name(form_field * ff1, form_field * ff2)
+int form_field_compare_name(dllist_t dl1, dllist_t dl2)
 {
+  form_field * ff1 = (form_field *)dl1;
+  form_field * ff2 = (form_field *)dl2;
+
   if(!ff1->name || !ff2->name)
     return FALSE;
 
@@ -452,7 +458,10 @@ form_info *form_info_dup(form_info * formi)
   retv->infos = NULL;
 
   for(ptr = formi->infos; ptr; ptr = ptr->next)
-    retv->infos = dllist_append(retv->infos, form_field_duplicate(ptr->data));
+  {
+    retv->infos = dllist_append(retv->infos,
+    (dllist_t) form_field_duplicate((form_field *)ptr->data));
+  }
 
   return retv;
 }
@@ -508,7 +517,7 @@ form_info *form_parse(char *form_text, int form_len)
         fstag = TRUE;
         plastformtag = lastformtag;
         lastformtag = form_parse_inputtag(stack);
-        retv->infos = dllist_append(retv->infos, lastformtag);
+        retv->infos = dllist_append(retv->infos, (dllist_t)lastformtag);
       }
       else if(retv && lastformtag && IS_TAG("/INPUT"))
       {
@@ -535,7 +544,7 @@ form_info *form_parse(char *form_text, int form_len)
 
         plastformtag = lastformtag;
         lastformtag = form_parse_buttontag(stack);
-        retv->infos = dllist_append(retv->infos, lastformtag);
+        retv->infos = dllist_append(retv->infos, (dllist_t)lastformtag);
       }
       else if(retv && lastformtag && IS_TAG("/BUTTON"))
       {
@@ -563,7 +572,7 @@ form_info *form_parse(char *form_text, int form_len)
         plastformtag = lastformtag;
         lastformtag = form_parse_selecttag(stack);
         selectgroup = lastformtag;
-        retv->infos = dllist_append(retv->infos, lastformtag);
+        retv->infos = dllist_append(retv->infos, (dllist_t)lastformtag);
       }
       else if(selectgroup && IS_TAG("/SELECT"))
       {
@@ -575,8 +584,9 @@ form_info *form_parse(char *form_text, int form_len)
         plastformtag = lastformtag;
         lastformtag = form_parse_optgrouptag(stack);
         optgroup = lastformtag;
-        optgroups = dllist_prepend(optgroups, lastformtag);
-        selectgroup->infos = dllist_append(selectgroup->infos, lastformtag);
+        optgroups = dllist_prepend(optgroups, (dllist_t) lastformtag);
+        selectgroup->infos = dllist_append(selectgroup->infos,
+        (dllist_t) lastformtag);
       }
       else if(optgroups && IS_TAG("/OPTGROUP"))
       {
@@ -594,9 +604,15 @@ form_info *form_parse(char *form_text, int form_len)
         lastformtag = form_parse_optiontag(stack);
         lastformtag->multiple = selectgroup->multiple;
         if(optgroup)
-          optgroup->infos = dllist_append(optgroup->infos, lastformtag);
+        {
+          optgroup->infos = dllist_append(optgroup->infos,
+          (dllist_t)lastformtag);
+        }
         else
-          selectgroup->infos = dllist_append(selectgroup->infos, lastformtag);
+        {
+          selectgroup->infos = dllist_append(selectgroup->infos,
+          (dllist_t) lastformtag);
+        }
       }
       else if(selectgroup && lastformtag && IS_TAG("/OPTION"))
       {
@@ -634,7 +650,7 @@ form_info *form_parse(char *form_text, int form_len)
         plastformtag = lastformtag;
         lastformtag = form_parse_textareatag(stack);
 
-        retv->infos = dllist_append(retv->infos, lastformtag);
+        retv->infos = dllist_append(retv->infos, (dllist_t)lastformtag);
       }
       else if(retv && lastformtag && IS_TAG("/TEXTAREA"))
       {
@@ -692,18 +708,19 @@ form_info *form_parse(char *form_text, int form_len)
           {
             last = dllist_last(optgroup->infos);
             optgroup->infos =
-              dllist_insert_before(optgroup->infos, last, ffi);
+              dllist_insert_before(optgroup->infos, last, (dllist_t) ffi);
           }
           else if(selectgroup)
           {
             last = dllist_last(selectgroup->infos);
             selectgroup->infos =
-              dllist_insert_before(selectgroup->infos, last, ffi);
+              dllist_insert_before(selectgroup->infos, last, (dllist_t) ffi);
           }
           else
           {
             last = dllist_last(retv->infos);
-            retv->infos = dllist_insert_before(retv->infos, last, ffi);
+            retv->infos = dllist_insert_before(retv->infos, last,
+            (dllist_t) ffi);
           }
         }
         tr = 0;
@@ -741,7 +758,7 @@ form_info *form_parse(char *form_text, int form_len)
         ffi->type = FORM_T_NONFORM;
         ffi->text = tl_strdup(sp);
 
-        retv->infos = dllist_append(retv->infos, ffi);
+        retv->infos = dllist_append(retv->infos, (dllist_t)ffi);
       }
     }
   }
@@ -806,7 +823,7 @@ void form_get_default_successful(char *name, dllist * fields, dllist ** retv)
 
       ff->name = tl_strdup(n);
       ff->value = v ? v : tl_strdup("");
-      *retv = dllist_append(*retv, ff);
+      *retv = dllist_append(*retv, (dllist_t)ff);
     }
     ptr = ptr->next;
   }
@@ -898,7 +915,7 @@ static void form_get_successful(char *name, dllist * fields, dllist ** retv)
 
       ff->name = tl_strdup(n);
       ff->value = v ? v : tl_strdup("");
-      *retv = dllist_append(*retv, ff);
+      *retv = dllist_append(*retv, (dllist_t)ff);
     }
   }
 }
@@ -922,7 +939,7 @@ static void form_submit_cb(GtkWidget * w, form_info * fi)
     ff->name = tl_strdup(ffi->name);
     ff->value =
       ffi->default_value ? tl_strdup(ffi->default_value) : tl_strdup("");
-    fields = dllist_prepend(fields, ff);
+    fields = dllist_prepend(fields, (dllist_t) ff);
   }
 
   ui = url_info_new(fi->action);
@@ -940,7 +957,7 @@ static void form_submit_cb(GtkWidget * w, form_info * fi)
       (GtkDestroyNotify) url_info_free);
   }
 
-  cfg.request = dllist_append(cfg.request, ui);
+  cfg.request = dllist_append(cfg.request, (dllist_t)ui);
 
   if(cfg.mode_started)
   {
