@@ -966,7 +966,7 @@ static bufio *ftp_connect(doc * docp, char *host, int port, char *ruser,
       {
         char *rsp;
 
-        sprintf(buf, "REST %d\r\n", docp->rest_pos);
+        sprintf(buf, "REST %ld\r\n", (long) docp->rest_pos);
         ftp_control_write(docp, buf, strlen(buf));
         DEBUG_PROTOC("%s", buf);
         if((reply = ftp_get_response(docp, &rsp, TRUE)) >= 400)
@@ -984,7 +984,7 @@ static bufio *ftp_connect(doc * docp, char *host, int port, char *ruser,
         }
         else
         {
-          sprintf(buf, "%d", docp->rest_pos);
+          sprintf(buf, "%ld", (long) docp->rest_pos);
           if(!strstr(rsp + 3, buf))
           {
             xprintf(1,
@@ -1484,6 +1484,7 @@ static ftp_url_extension *ftp_list_unix_parse_line(char *str, char **fname,
   char month[2000];
   char rest[2000];
   unsigned int pi, day;
+  unsigned long size;
   char *nm, *sln;
 
   *fname = NULL;
@@ -1498,16 +1499,17 @@ static ftp_url_extension *ftp_list_unix_parse_line(char *str, char **fname,
     return NULL;
   }
   /* for SYS V style ls -l */
-  else if(sscanf(str, "%1999s %u %1999s %1999s %u %1999s %u %1999s %1999[^\n\r]",
-          attrib, &pi, pom, pom, &(ret->size), month, &day, rest, name) != 9)
+  else if(sscanf(str, "%1999s %u %1999s %1999s %lu %1999s %u %1999s %1999[^\n\r]",
+          attrib, &pi, pom, pom, &size, month, &day, rest, name) != 9)
   {
     /* for old BSD style ls -l */
-    if(sscanf(str, "%1999s %u %1999s %u %1999s %u %1999s %1999[^\n\r]",
-              attrib, &pi, pom, &(ret->size), month, &day, rest, name) != 8)
+    if(sscanf(str, "%1999s %u %1999s %lu %1999s %u %1999s %1999[^\n\r]",
+              attrib, &pi, pom, &size, month, &day, rest, name) != 8)
     {
       return NULL;
     }
   }
+  ret->size = size;
 
   ret->type = ftp_list_unix_perm_type(attrib);
   ret->perm = ftp_list_unix_perm_parse(attrib);
@@ -1579,14 +1581,16 @@ static ftp_url_extension *ftp_list_novel_parse_line(char *str, char **fname,
   char name[4000];
   char attrib[2000];
   unsigned int pi;
+  unsigned long size;
 
   *fname = NULL;
 
-  if(sscanf(str, "%1999s %u %1999s %u %1999s %u %1999s %3999[^\n\r]",
-     attrib, &pi, pom, &(ret->size), pom, &pi, pom, name) != 8)
+  if(sscanf(str, "%1999s %u %1999s %lu %1999s %u %1999s %3999[^\n\r]",
+     attrib, &pi, pom, &size, pom, &pi, pom, name) != 8)
   {
     return NULL;
   }
+  ret->size = size;
 
   ret->type = *attrib == 'd' ? FTP_TYPE_D : FTP_TYPE_F;
   ret->slink = NULL;
@@ -1802,10 +1806,10 @@ static void ftp_list_unix_dir_to_html(doc * docp)
         "" : "/", name, (ext->type == FTP_TYPE_D) ? "/" : "");
 
     snprintf(pom, sizeof(pom),
-      "<LI><A PAVUKEXT=\"FTPINF %u %hu %u %u %s\" HREF=\"%s\">&quot;%s&quot;</A> (%ub)\n",
-      (unsigned int) ext->type, ext->perm, ext->size,
+      "<LI><A PAVUKEXT=\"FTPINF %u %hu %lu %u %s\" HREF=\"%s\">&quot;%s&quot;</A> (%lub)\n",
+      (unsigned int) ext->type, ext->perm, (long)ext->size,
       (unsigned int) ext->time, (ext->slink ? ext->slink : ""), urlstr, name,
-      ext->size);
+      (long)ext->size);
 
     _free(name);
     _free(ext->slink);
@@ -1964,7 +1968,7 @@ void ftp_handshake_info_free(ftp_handshake_info * fhi)
 
   for(; fhi->infos; fhi->infos = dllist_remove_entry(fhi->infos, fhi->infos))
   {
-    ftp_handshake_info_data *d = fhi->infos->data;
+    ftp_handshake_info_data *d = (ftp_handshake_info_data *) fhi->infos->data;
     _free(d->cmd);
     _free(d);
   }
@@ -2020,7 +2024,7 @@ ftp_handshake_info *ftp_handshake_info_parse(char *host, char *str)
         if(!d->response && errno == ERANGE)
           ok = FALSE;
         _free(array[i]);
-        rv->infos = dllist_append(rv->infos, d);
+        rv->infos = dllist_append(rv->infos, (dllist_t) d);
         d = NULL;
       }
     }
@@ -2058,13 +2062,13 @@ ftp_handshake_info *ftp_handshake_info_dup(ftp_handshake_info * fhi)
   {
     ftp_handshake_info_data *d1, *d2;
 
-    d1 = ptr->data;
+    d1 = (ftp_handshake_info_data *) ptr->data;
 
     d2 = _malloc(sizeof(ftp_handshake_info_data));
     d2->response = d1->response;
     d2->cmd = tl_strdup(d1->cmd);
 
-    rv->infos = dllist_append(rv->infos, d2);
+    rv->infos = dllist_append(rv->infos, (dllist_t) d2);
   }
 
   return rv;
@@ -2079,13 +2083,13 @@ char *ftp_handshake_info_data_dump(ftp_handshake_info * fhi)
 
   if(fhi->infos)
   {
-    d = fhi->infos->data;
+    d = (ftp_handshake_info_data *) fhi->infos->data;
     snprintf(pom, sizeof(pom), "%s\\%d", d->cmd, d->response);
     rv = tl_strdup(pom);
 
     for(ptr = fhi->infos->next; ptr; ptr = ptr->next)
     {
-      d = ptr->data;
+      d = (ftp_handshake_info_data *) ptr->data;
       snprintf(pom, sizeof(pom), "\\%s\\%d", d->cmd, d->response);
       rv = tl_str_append(rv, pom);
     }
@@ -2099,7 +2103,7 @@ static ftp_handshake_info *ftp_handshake_info_data_find(char *host, int port)
 
   for(ptr = priv_cfg.ftp_login_hs; ptr; ptr = ptr->next)
   {
-    ftp_handshake_info *fhi = ptr->data;
+    ftp_handshake_info *fhi = (ftp_handshake_info *) ptr->data;
 
     if((fhi->port == port || !host[0]) && !strcmp(fhi->host, host))
       return fhi;
@@ -2175,7 +2179,7 @@ static int ftp_do_login_handshake_cust(ftp_handshake_info * fhi, doc * docp,
 
   for(ptr = fhi->infos; ptr; ptr = ptr->next)
   {
-    ftp_handshake_info_data *d = ptr->data;
+    ftp_handshake_info_data *d = (ftp_handshake_info_data *) ptr->data;
     char *cmd;
     int response;
 
