@@ -103,7 +103,7 @@ static url_info *cfg_url_dlg_get_url_info(struct cfg_url_dlg_t *urldlg)
     gtk_clist_get_text(GTK_CLIST(urldlg->field_list), row, 2, &p);
     ff->value = form_decode_urlencoded_str(p, strlen(p));
 
-    ui->fields = dllist_append(ui->fields, ff);
+    ui->fields = dllist_append(ui->fields, (dllist_t) ff);
   }
 
   return ui;
