@@ -229,7 +229,7 @@ void gui_window_drop_url(GtkWidget * widget, GdkDragContext * context,
       (GtkDestroyNotify) url_info_free);
   }
 
-  cfg.request = dllist_append(cfg.request, ui);
+  cfg.request = dllist_append(cfg.request, (dllist_t) ui);
 
 #ifdef DEBUG
   if(cfg.debug)
@@ -428,7 +428,7 @@ static void FetchURL(GtkWidget * widget, GtkSelectionData * selection_data,
       (GtkDestroyNotify) url_info_free);
   }
 
-  cfg.request = dllist_append(cfg.request, ui);
+  cfg.request = dllist_append(cfg.request, (dllist_t) ui);
 
 #ifdef DEBUG
   if(cfg.debug)
@@ -469,7 +469,7 @@ static void AddBrowserURL(GtkWidget * w)
         (GtkDestroyNotify) url_info_free);
     }
 
-    cfg.request = dllist_append(cfg.request, ui);
+    cfg.request = dllist_append(cfg.request, (dllist_t) ui);
 
 
 #ifdef DEBUG
@@ -682,7 +682,6 @@ static void Quit(GtkObject * object, gpointer func_data)
 
     gkey_save();
 
-    pavuk_do_at_exit();
     gtk_exit(0);
   }
 }
@@ -2368,10 +2367,7 @@ void gui_main(void)
   }
 #endif
 
-  pavuk_do_at_exit();
-
-  /*** required, because of some gtk atexit() hanged functions ***/
-  _exit(cfg.fail_cnt ? PAVUK_EXIT_DOC_ERR : PAVUK_EXIT_OK);
+  exit(cfg.fail_cnt ? PAVUK_EXIT_DOC_ERR : PAVUK_EXIT_OK);
 }
 
 #endif
