@@ -27,12 +27,12 @@ static dlhash *html_parser_tag_hash = NULL;
 #define ADVERT_PREFIX "adv<!-- Removed by pavuk "
 #define ADVERT_SUFFIX " -->"
 
-static int html_parser_tag_comp_func(void *key1, void *key2)
+static int html_parser_tag_comp_func(dllist_t key1, dllist_t key2)
 {
-  return (!strcasecmp(key1, key2));
+  return (!strcasecmp((void *) key1, (void *) key2));
 }
 
-static unsigned int html_parser_tag_hash_func(unsigned int size, void *key)
+static unsigned int html_parser_tag_hash_func(unsigned int size, dllist_t key)
 {
   unsigned char *p = (unsigned char *) key;
   unsigned int retv = 0;
@@ -46,9 +46,9 @@ static unsigned int html_parser_tag_hash_func(unsigned int size, void *key)
   return retv;
 }
 
-static void *html_parser_tag_key_func(void *data)
+static dllist_t html_parser_tag_key_func(dllist_t data)
 {
-  return ((html_tag_t *) data)->tag;
+  return (dllist_t) ((html_tag_t *) data)->tag;
 }
 
 html_parser_t *html_parser_init(html_tag_t * tags, int ntags,
@@ -97,7 +97,7 @@ html_parser_t *html_parser_init(html_tag_t * tags, int ntags,
       html_parser_tag_hash_func, html_parser_tag_comp_func);
 
     for(i = 0; i < ntags; i++)
-      dlhash_insert(rv->tag_hash, &tags[i]);
+      dlhash_insert(rv->tag_hash, (dllist_t) &tags[i]);
 
     html_parser_tag_hash = rv->tag_hash;
 
@@ -118,7 +118,7 @@ void html_parser_kill(html_parser_t * hpinfo)
 #define KILL_FUNC_CHAIN(chain) \
   while (chain) \
   { \
-    _free(chain->data);\
+    if(chain->data) free((void *)chain->data);\
     chain = dllist_remove_entry(chain, chain);\
   }
 
@@ -143,7 +143,7 @@ void html_parser_add_tag_func(html_parser_t * hpinfo, html_parser_func_t func,
   nfunc = _malloc(sizeof(html_parser_func_info_t));
   nfunc->func = func;
   nfunc->data = data;
-  hpinfo->tag_funcs = dllist_append(hpinfo->tag_funcs, nfunc);
+  hpinfo->tag_funcs = dllist_append(hpinfo->tag_funcs, (dllist_t) nfunc);
 }
 
 void html_parser_add_attrib_func(html_parser_t * hpinfo,
@@ -154,7 +154,7 @@ void html_parser_add_attrib_func(html_parser_t * hpinfo,
   nfunc = _malloc(sizeof(html_parser_func_info_t));
   nfunc->func = func;
   nfunc->data = data;
-  hpinfo->attrib_funcs = dllist_append(hpinfo->attrib_funcs, nfunc);
+  hpinfo->attrib_funcs = dllist_append(hpinfo->attrib_funcs, (dllist_t) nfunc);
 }
 
 void html_parser_add_style_func(html_parser_t * hpinfo,
@@ -165,7 +165,7 @@ void html_parser_add_style_func(html_parser_t * hpinfo,
   nfunc = _malloc(sizeof(html_parser_func_info_t));
   nfunc->func = func;
   nfunc->data = data;
-  hpinfo->style_funcs = dllist_append(hpinfo->style_funcs, nfunc);
+  hpinfo->style_funcs = dllist_append(hpinfo->style_funcs, (dllist_t) nfunc);
 }
 
 void html_parser_add_script_func(html_parser_t * hpinfo,
@@ -176,7 +176,7 @@ void html_parser_add_script_func(html_parser_t * hpinfo,
   nfunc = _malloc(sizeof(html_parser_func_info_t));
   nfunc->func = func;
   nfunc->data = data;
-  hpinfo->script_funcs = dllist_append(hpinfo->script_funcs, nfunc);
+  hpinfo->script_funcs = dllist_append(hpinfo->script_funcs, (dllist_t) nfunc);
 }
 
 void html_parser_set_document(html_parser_t * hpinfo, url * doc_url,
@@ -259,7 +259,7 @@ static void html_parser_call_funcs(html_parser_t * hpinfo, dllist * funcs)
 
   for(ptr = funcs; ptr; ptr = ptr->next)
   {
-    html_parser_func_info_t *fi = ptr->data;
+    html_parser_func_info_t *fi = (html_parser_func_info_t *) ptr->data;
 
     fi->func(hpinfo, hpinfo->stack, fi->data);
   }
@@ -292,7 +292,8 @@ static int html_parser_check_tag(html_parser_t * hpinfo, char *tagstart)
     char *tagname;
 
     tagname = tl_strndup(tagstart, tl);
-    hpinfo->current_tag = dlhash_find_by_key(hpinfo->tag_hash, tagname);
+    hpinfo->current_tag = (html_tag_t *) dlhash_find_by_key(hpinfo->tag_hash,
+    (dllist_t) tagname);
     _free(tagname);
   }
   return (hpinfo->current_tag != NULL);
@@ -557,7 +558,7 @@ void html_parser_parse_tag(html_parser_t * hpinfo, char *stack, void *data)
     for(ptr = cfg.dont_touch_url_rpattern;
       ptr && hpinfo->tag_attrib; ptr = ptr->next)
     {
-      if(re_pmatch(ptr->data, hpinfo->tag_attrib))
+      if(re_pmatch((re_entry *) ptr->data, hpinfo->tag_attrib))
         _free(hpinfo->tag_attrib);
     }
 
@@ -565,7 +566,7 @@ void html_parser_parse_tag(html_parser_t * hpinfo, char *stack, void *data)
     for(ptr = cfg.dont_touch_tag_rpattern;
       ptr && hpinfo->tag_attrib; ptr = ptr->next)
     {
-      if(re_pmatch(ptr->data, hpinfo->stack))
+      if(re_pmatch((re_entry *)ptr->data, hpinfo->stack))
         _free(hpinfo->tag_attrib);
     }
 #endif
@@ -756,7 +757,7 @@ void html_parser_parse_tag_jstransform(html_parser_t * hpinfo, char *stack,
 
   for(ptr = priv_cfg.js_transform; ptr; ptr = ptr->next)
   {
-    js_transform_t *jt = ptr->data;
+    js_transform_t *jt = (js_transform_t *) ptr->data;
 
     if(js_transform_match_tag(jt, hpinfo->stack))
     {
@@ -874,7 +875,8 @@ void html_parser_process_form(html_parser_t * hpinfo, char *stack,
 
     if(formlist && hpinfo->tag_attrib)
     {
-      *formlist = dllist_append(*formlist, tl_strdup(hpinfo->tag_attrib));
+      *formlist = dllist_append(*formlist,
+      (dllist_t) tl_strdup(hpinfo->tag_attrib));
     }
   }
 }
@@ -917,7 +919,8 @@ void html_parser_get_url(html_parser_t * hpinfo, char *stack,
       purl->status |= URL_ISSCRIPT;
 
     purl->level = hpinfo->doc_url->level + 1;
-    purl->parent_url = dllist_append(purl->parent_url, hpinfo->doc_url);
+    purl->parent_url = dllist_append(purl->parent_url,
+    (dllist_t) hpinfo->doc_url);
 
     /*****************************************************/
     /* if we are in SYNC/MIRROR mode try to get original */
@@ -948,7 +951,7 @@ void html_parser_get_url(html_parser_t * hpinfo, char *stack,
     {
       DEBUG_HTML("Removing server image map\n");
       free_deep_url((url *) einfo->prev_a->data);
-      _free(einfo->prev_a->data);
+      free((url *) einfo->prev_a->data);
       einfo->urls = dllist_remove_entry(einfo->urls, einfo->prev_a);
       einfo->prev_a = NULL;
     }
@@ -999,7 +1002,7 @@ void html_parser_get_url(html_parser_t * hpinfo, char *stack,
         _free(pext);
       }
 
-      einfo->urls = dllist_append(einfo->urls, purl);
+      einfo->urls = dllist_append(einfo->urls, (dllist_t) purl);
 
       if(hpinfo->current_tag->type == HTML_TAG_A &&
         hpinfo->current_attrib->type == HTML_ATTRIB_HREF)
@@ -1053,9 +1056,10 @@ void html_parser_url_to_local(html_parser_t * hpinfo, char *stack,
   {
     dllist *ptr;
 
-    ptr = dllist_find2(rinfo->einfo->urls, urlp, (dlcomp_func) url_compare);
+    ptr = dllist_find2(rinfo->einfo->urls, (dllist_t) urlp,
+    dllist_url_compare);
     if(ptr)
-      before_url = ptr->data;
+      before_url = (url *) ptr->data;
   }
 
   if(before_url)
@@ -1460,7 +1464,7 @@ void html_parser_parse_body_jstransform(html_parser_t * hpinfo, char *stack,
     for(ptr = priv_cfg.js_transform; ptr; ptr = ptr->next)
     {
       int nsub, *subs;
-      js_transform_t *jt = ptr->data;
+      js_transform_t *jt = (js_transform_t *) ptr->data;
 
       if(jt->tag[0])
         continue;
