@@ -605,10 +605,10 @@ int lfname_match(lfname * lfnamep, const char *urlstr)
 #elif defined(HAVE_BSD_REGEX)
     re_comp(lfnamep->matchstr);
     return re_exec(urlstr);
-#elif definded(HAVE_GNU_REGEX)
+#elif defined(HAVE_GNU_REGEX)
     return re_match(&(lfnamep->preg), urlstr, strlen(urlstr), 0,
       &lfnamep->pmatch) >= 0;
-#elif definded(HAVE_PCRE_REGEX)
+#elif defined(HAVE_PCRE_REGEX)
     return pcre_exec(lfnamep->preg, lfnamep->preg_extra, urlstr,
       strlen(urlstr), 0, 0, lfnamep->pmatch, 3 * lfnamep->pmatch_nr) >= 0;
 #endif
@@ -1224,7 +1224,7 @@ static int lfname_lsp_eval(struct lfname_lsp_interp *interp,
     break;
   case LF_LSP_HASH:
     var->ret_val.num = str_hash_func(var->param2->ret_val.num,
-      var->param1->ret_val.str);
+      (dllist_t) var->param1->ret_val.str);
     break;
   case LF_LSP_MD5:
     var->ret_val.str = _md5(var->param1->ret_val.str);
