@@ -110,6 +110,22 @@ static void pavuk_quit(int signum)
   cfg.stop = TRUE;
 }
 
+static void pavuk_alarm(int signum)
+{
+  printf(gettext("Program has been forcefully terminated\n"));
+  exit(10);
+}
+
+static void pavuk_end(int signum)
+{
+  signal(SIGALRM, pavuk_alarm);
+  printf(gettext("TERM signal catched\n"));
+  cfg.xi_face = FALSE;
+  cfg.rbreak = TRUE;
+  cfg.stop = TRUE;
+  alarm(1);
+}
+
 static void init_values(int argc, char **argv)
 {
   char *d;
@@ -307,7 +323,6 @@ static void init_values(int argc, char **argv)
       xprintf(0,
         gettext("Error: Supplied bad file descriptor in -dumpfd option\n"),
         cfg.dumpfd);
-      pavuk_do_at_exit();
       exit(PAVUK_EXIT_CFG_ERR);
     }
   }
@@ -320,14 +335,13 @@ static void init_values(int argc, char **argv)
         gettext
         ("Error: Supplied bad file descriptor in -dump_urlfd option\n"),
         cfg.dumpfd);
-      pavuk_do_at_exit();
       exit(PAVUK_EXIT_CFG_ERR);
     }
   }
 
   cfg.url_hash_tbl =
     dlhash_new(cfg.hash_size, url_key_func, url_hash_func,
-    (dlcomp_func) url_compare);
+    dllist_url_compare);
   dlhash_set_free_func(cfg.url_hash_tbl, url_free_func, NULL);
   cfg.fn_hash_tbl =
     dlhash_new(cfg.hash_size, fn_key_func, str_hash_func, str_comp_func);
@@ -376,7 +390,6 @@ static void init_values(int argc, char **argv)
         ("WARNING: scndir not specified - saving to current directory\n"));
       cfg_dump(cfg.save_scn);
     }
-    pavuk_do_at_exit();
     exit(PAVUK_EXIT_OK);
   }
 
@@ -420,7 +433,7 @@ static void init_values(int argc, char **argv)
     {
       xprintf(0, gettext("Pavuk will run at backround as PID %d\n"),
         (int) ppid);
-      _exit(PAVUK_EXIT_CFG_ERR);
+      exit(PAVUK_EXIT_CFG_ERR);
     }
 #ifdef __CYGWIN__
     FreeConsole();
@@ -461,7 +474,7 @@ static void read_urls(char *filename)
       url_info *ui;
 
       ui = url_info_new(lnbuf);
-      cfg.request = dllist_append(cfg.request, ui);
+      cfg.request = dllist_append(cfg.request, (dllist_t) ui);
     }
   }
 
@@ -479,6 +492,7 @@ int main(int argc, char **argv)
   time_t __time = time(NULL);
 
   init_values(argc, argv);
+  atexit(pavuk_do_at_exit);
 
   /*
      pro: We do not fully trust pavuk to stop working after the timeout
@@ -503,6 +517,9 @@ int main(int argc, char **argv)
    */
   srand(time(NULL) ^ getpid());
 
+  signal(SIGINT, pavuk_end);
+  signal(SIGTERM, pavuk_end);
+  signal(SIGALRM, pavuk_end);
   signal(SIGPIPE, SIG_IGN);
 /**** spustenie algoritmu alebo rozhrania ****/
 /**** FIXME: Translate me!                ****/
@@ -539,6 +556,5 @@ int main(int argc, char **argv)
   }
 
   log_start(NULL);
-  pavuk_do_at_exit();
   return cfg.fail_cnt ? PAVUK_EXIT_DOC_ERR : PAVUK_EXIT_OK;
 }
