@@ -76,7 +76,7 @@ static void reschedule_url(url * urlp)
 {
   DEBUG_MISC(gettext("Rescheduling locked URL as no. %d\n"), cfg.total_cnt);
   LOCK_CFG_URLSTACK;
-  cfg.urlstack = dllist_append(cfg.urlstack, urlp);
+  cfg.urlstack = dllist_append(cfg.urlstack, (dllist_t) urlp);
 #ifdef HAVE_MT
   mt_semaphore_up(&cfg.urlstack_sem);
 #endif
@@ -125,7 +125,7 @@ static void add_matching_form(doc * docp, int nform, url_info * ui)
   fields = NULL;
   for(ptr = ui->fields; ptr; ptr = ptr->next)
   {
-    fields = dllist_prepend(fields,
+    fields = dllist_prepend(fields, (dllist_t)
       form_field_duplicate((form_field *) ptr->data));
   }
 
@@ -137,8 +137,7 @@ static void add_matching_form(doc * docp, int nform, url_info * ui)
   {
     form_field *ff = (form_field *) sfields->data;
 
-    if(dllist_find2(fields, (void *) ff,
-        (dlcomp_func) form_field_compare_name))
+    if(dllist_find2(fields, (dllist_t) ff, form_field_compare_name))
     {
       _free(ff->name);
       _free(ff->value);
@@ -146,7 +145,7 @@ static void add_matching_form(doc * docp, int nform, url_info * ui)
     }
     else
     {
-      fields = dllist_prepend(fields, ff);
+      fields = dllist_prepend(fields, (dllist_t) ff);
     }
   }
 
@@ -290,13 +289,10 @@ int process_document(doc * docu, int check_lim)
         SETNEXTURL;
       }
 
-      if(!prottable[urlr->type].supported ||
-        (urlr->parent_url &&
-          (urlr->type == URLT_FTP ||
-            urlr->type == URLT_FTPS) &&
-          urlr->p.ftp.dir &&
-          !cfg.condition.ftpdir) ||
-        (urlr->parent_url && !url_append_condition(urlr, &condp)))
+      if(!prottable[urlr->type].supported || (urlr->parent_url
+      && (urlr->type == URLT_FTP || urlr->type == URLT_FTPS)
+      && urlr->p.ftp.dir && !cfg.condition.ftpdir)
+      || (urlr->parent_url && !url_append_condition(urlr, &condp)))
       {
         xprintf(1, gettext("Disallowed by rules\n"));
 
@@ -369,6 +365,7 @@ int process_document(doc * docu, int check_lim)
 #ifdef I_FACE
     if(cfg.stop || cfg.rbreak)
     {
+      _free(pstr);
       break;
     }
 #endif
@@ -534,7 +531,6 @@ int process_document(doc * docu, int check_lim)
         urlr->status |= URL_PROCESSED;
         urlr->status |= URL_ERR_REC;
         SETNEXTURL;
-
       }
       else
       {
@@ -604,7 +600,7 @@ int process_document(doc * docu, int check_lim)
           add_matching_forms(docu, formlist);
           while(formlist)
           {
-            _free(formlist->data);
+            if(formlist->data) free((void *) formlist->data);
             formlist = dllist_remove_entry(formlist, formlist);
           }
         }
@@ -615,7 +611,6 @@ int process_document(doc * docu, int check_lim)
           gui_tree_add_start();
           cat_links_to_url_list(urls);
           gui_tree_add_end();
-
         }
         else if(cfg.mode == MODE_FTPDIR)
         {
@@ -626,7 +621,7 @@ int process_document(doc * docu, int check_lim)
           for(; urls; urls = dllist_remove_entry(urls, urls))
           {
             free_deep_url((url *) urls->data);
-            _free(urls->data);
+            if(urls->data) free((url *)urls->data);
           }
         }
 
@@ -775,6 +770,7 @@ int download_single_doc(url * urlp)
 
 /*********************************************/
 /* rekurzivne prechadzanie stromu dokumentov */
+/* FIXME: Translate me                       */
 /*********************************************/
 #ifdef HAVE_MT
 static void _recurse(int thnr)
@@ -842,7 +838,7 @@ void recurse(int thnr)
     {
       LOCK_CFG_URLSTACK;
       cfg.docnr--;
-      cfg.urlstack = dllist_prepend(cfg.urlstack, urlp);
+      cfg.urlstack = dllist_prepend(cfg.urlstack, (dllist_t) urlp);
 #ifdef HAVE_MT
       mt_semaphore_up(&cfg.urlstack_sem);
 #endif
@@ -1021,7 +1017,7 @@ static void dump_ftp_list(dllist * urllst)
     url *urlp = (url *) ptr->data;
     void *dupl;
 
-    dupl = dllist_find2(ptr->next, urlp, (dlcomp_func) url_compare);
+    dupl = dllist_find2(ptr->next, (dllist_t) urlp, dllist_url_compare);
 
     if(!dupl && !(urlp->status & URL_INLINE_OBJ) &&
       (urlp->type == URLT_FTP || urlp->type == URLT_FTPS))
@@ -1070,7 +1066,7 @@ static void dump_urls_list(dllist * urls)
   {
     void *dupl;
 
-    dupl = dllist_find2(ptr->next, ptr->data, (dlcomp_func) url_compare);
+    dupl = dllist_find2(ptr->next, (dllist_t) ptr->data, dllist_url_compare);
 
     if(!dupl)
     {
@@ -1195,7 +1191,7 @@ void get_urls_to_synchronize(char *dirname, dllist ** list)
         purl->extension = ftp_url_ext_new(FTP_TYPE_D, -1, -1, NULL, 0);
         url_set_filename(purl,
           tl_str_concat(NULL, next_dir, priv_cfg.index_name, NULL));
-        *list = dllist_prepend(*list, purl);
+        *list = dllist_prepend(*list, (dllist_t) purl);
       }
       else if(purl)
       {
@@ -1239,7 +1235,7 @@ void get_urls_to_synchronize(char *dirname, dllist ** list)
         purl->status |= URL_ISSTARTING;
 
         url_set_filename(purl, tl_strdup(next_dir));
-        *list = dllist_prepend(*list, purl);
+        *list = dllist_prepend(*list, (dllist_t) purl);
       }
     }
     else
@@ -1273,7 +1269,7 @@ void get_urls_to_synchronize(char *dirname, dllist ** list)
 
         purl->status |= URL_ISSTARTING;
         url_set_filename(purl, tl_strdup(next_dir));
-        *list = dllist_prepend(*list, purl);
+        *list = dllist_prepend(*list, (dllist_t) purl);
       }
     }
 
