@@ -770,7 +770,7 @@ dllist *tl_numlist_split(char *str, char *sep)
 
   for(i = 0; v && v[i]; i++)
   {
-    int n = _atoi(v[i]);
+    long n = _atoi(v[i]);
     if(errno == ERANGE)
     {
       while(rv)
@@ -778,7 +778,7 @@ dllist *tl_numlist_split(char *str, char *sep)
       break;
     }
 
-    rv = dllist_append(rv, (void *) n);
+    rv = dllist_append(rv, (dllist_t) n);
   }
 
   tl_strv_free(v);
