@@ -840,7 +840,7 @@ char *url_to_absolute_url(char *base, char *baset, url * parent, char *act)
 /**************************************/
 static char *url_encode_str_real(char *urlstr, char *unsafe, int safety)
 {
-  unsigned char *res, *p, *r;
+  char *res, *p, *r;
 
   if(urlstr == NULL)
     return NULL;
@@ -1088,7 +1088,7 @@ void cat_links_to_url_list(dllist * l1)
       {
         link_url_in_list(same, (url *) p->data);
         free_deep_url((url *) p->data);
-        _free(p->data);
+        free((url *)p->data);
       }
       else
       {
@@ -1117,14 +1117,14 @@ void cat_links_to_url_list(dllist * l1)
         {
         case SSTRAT_DO_SIRKY:
         case SSTRAT_DO_HLBKY:
-          reg = dllist_append(reg, p->data);
+          reg = dllist_append(reg, (dllist_t)p->data);
           break;
         case SSTRAT_DO_SIRKY_I:
         case SSTRAT_DO_HLBKY_I:
           if(urlp->status & URL_INLINE_OBJ)
-            inl = dllist_append(inl, urlp);
+            inl = dllist_append(inl, (dllist_t)urlp);
           else
-            reg = dllist_append(reg, urlp);
+            reg = dllist_append(reg, (dllist_t)urlp);
           break;
         default:
           break;
@@ -1143,7 +1143,7 @@ void cat_links_to_url_list(dllist * l1)
             pom[1] = '\0';
             nurl = url_parse(ustr);
             assert(nurl->type != URLT_FROMPARENT);
-            dllist_append(p, nurl);
+            dllist_append(p, (dllist_t) nurl);
           }
           _free(ustr);
         }
@@ -1156,7 +1156,7 @@ void cat_links_to_url_list(dllist * l1)
       UNLOCK_REJCNT;
 
       free_deep_url((url *) p->data);
-      _free(p->data);
+      free((url *)p->data);
     }
 
     p = p->next;
@@ -1213,7 +1213,7 @@ void append_url_to_list(url * urlp)
 #endif
 
   url_add_to_url_hash_tab(urlp);
-  cfg.urlstack = dllist_append(cfg.urlstack, urlp);
+  cfg.urlstack = dllist_append(cfg.urlstack, (dllist_t) urlp);
   cfg.total_cnt++;
 
 
@@ -1251,7 +1251,7 @@ void link_url_in_list(url * orig, url * copy)
     {
       LOCK_URL(orig);
       for(ptr = orig->parent_url; ptr; ptr = ptr->next)
-        if(ptr->data == cpar)
+        if((url *)ptr->data == cpar)
           found = TRUE;
       UNLOCK_URL(orig);
     }
@@ -1262,7 +1262,7 @@ void link_url_in_list(url * orig, url * copy)
       LOCK_URL(orig);
       orig->ref_cnt++;
       if(cpar)
-        orig->parent_url = dllist_append(orig->parent_url, cpar);
+        orig->parent_url = dllist_append(orig->parent_url, (dllist_t) cpar);
 
 #ifdef WITH_TREE
 #ifdef I_FACE
@@ -1318,7 +1318,7 @@ int url_redirect_to(url * src, url * dst, int is_303)
 
     LOCK_URL(pomurl);
 
-    pomurl->parent_url = dllist_append(pomurl->parent_url, src);
+    pomurl->parent_url = dllist_append(pomurl->parent_url, (dllist_t) src);
     pomurl->ref_cnt++;
 
     src->moved_to = pomurl;
@@ -1359,7 +1359,7 @@ int url_redirect_to(url * src, url * dst, int is_303)
   }
   else
   {
-    dst->parent_url = dllist_append(dst->parent_url, src);
+    dst->parent_url = dllist_append(dst->parent_url, (dllist_t) src);
     src->moved_to = dst;
     src->status |= URL_MOVED;
 
@@ -1386,7 +1386,7 @@ void url_add_to_url_hash_tab(url * urlp)
   url_clear_anchor(urlp);
 
   LOCK_CFG_URLHASH;
-  dlhash_insert(cfg.url_hash_tbl, urlp);
+  dlhash_insert(cfg.url_hash_tbl, (dllist_t) urlp);
   UNLOCK_CFG_URLHASH;
 }
 
@@ -1396,7 +1396,7 @@ void url_remove_from_url_hash_tab(url * urlp)
     return;
 
   LOCK_CFG_URLHASH;
-  dlhash_exclude(cfg.url_hash_tbl, urlp);
+  dlhash_exclude(cfg.url_hash_tbl, (dllist_t) urlp);
   UNLOCK_CFG_URLHASH;
 }
 
@@ -1416,7 +1416,7 @@ void url_remove_from_file_hash_tab(url * urlp)
   if(urlp->local_name)
   {
     LOCK_CFG_FILEHASH;
-    dlhash_exclude_exact(cfg.fn_hash_tbl, urlp);
+    dlhash_exclude_exact(cfg.fn_hash_tbl, (dllist_t) urlp);
     UNLOCK_CFG_FILEHASH;
   }
 }
@@ -1730,12 +1730,12 @@ int lockfn)
       url *inhash;
 
       LOCK_CFG_FILEHASH;
-      inhash = dlhash_find_by_key(cfg.fn_hash_tbl, p);
+      inhash = (url *) dlhash_find_by_key(cfg.fn_hash_tbl, (dllist_t) p);
 
       if(!inhash && !inserted)
       {
         urlp->local_name = p;
-        dlhash_insert(cfg.fn_hash_tbl, urlp);
+        dlhash_insert(cfg.fn_hash_tbl, (dllist_t) urlp);
         inserted = TRUE;
       }
 
@@ -1771,11 +1771,12 @@ int lockfn)
             i++;
             snprintf(pom, pomlen, "%s/%03d%s", p, i, f);
             LOCK_CFG_FILEHASH;
-            inhash = dlhash_find_by_key(cfg.fn_hash_tbl, pom);
+            inhash = (url *) dlhash_find_by_key(cfg.fn_hash_tbl,
+            (dllist_t) pom);
             if(!inhash && !inserted)
             {
               urlp->local_name = pom;
-              dlhash_insert(cfg.fn_hash_tbl, urlp);
+              dlhash_insert(cfg.fn_hash_tbl, (dllist_t) urlp);
               inserted = TRUE;
             }
             UNLOCK_CFG_FILEHASH;
@@ -1792,7 +1793,7 @@ int lockfn)
     {
       LOCK_CFG_FILEHASH;
       urlp->local_name = p;
-      dlhash_insert(cfg.fn_hash_tbl, urlp);
+      dlhash_insert(cfg.fn_hash_tbl, (dllist_t) urlp);
       inserted = TRUE;
       UNLOCK_CFG_FILEHASH;
     }
@@ -1814,7 +1815,7 @@ void url_set_filename(url * urlp, char *local_name)
 {
   LOCK_CFG_FILEHASH;
   urlp->local_name = local_name;
-  dlhash_insert(cfg.fn_hash_tbl, urlp);
+  dlhash_insert(cfg.fn_hash_tbl, (dllist_t) urlp);
   UNLOCK_CFG_FILEHASH;
 
 }
@@ -2686,7 +2687,7 @@ url *url_was_befor(url * urlp)
     return NULL;
 
   LOCK_CFG_URLHASH;
-  ret = (url *) dlhash_find(cfg.url_hash_tbl, urlp);
+  ret = (url *) dlhash_find(cfg.url_hash_tbl, (dllist_t) urlp);
   UNLOCK_CFG_URLHASH;
 
   return ret;
@@ -2700,6 +2701,11 @@ void url_forget_filename(url * urlp)
   _free(urlp->local_name);
 }
 
+int dllist_url_compare(dllist_t key1, dllist_t key2)
+{
+  return url_compare((url *) key1, (url *) key2);
+}
+
 int url_compare(url * u1, url * u2)
 {
   int rv;
@@ -2761,8 +2767,7 @@ int url_compare(url * u1, url * u2)
       ptr = fi1->infos;
       while(ptr)
       {
-        if(!dllist_find2(fi2->infos, ptr->data,
-            (dlcomp_func) form_field_compare))
+        if(!dllist_find2(fi2->infos, ptr->data, form_field_compare))
           return FALSE;
         ptr = ptr->next;
       }
@@ -2996,7 +3001,7 @@ url_info *url_info_parse(char *str)
           _free(fi);
         }
         else
-          ui->fields = dllist_append(ui->fields, fi);
+          ui->fields = dllist_append(ui->fields, (dllist_t) fi);
       }
       break;
     }
@@ -3108,7 +3113,7 @@ url_info *url_info_duplicate(url_info * ui)
     cff->name = tl_strdup(ff->name);
     cff->value = tl_strdup(ff->value);
 
-    cui->fields = dllist_append(cui->fields, cff);
+    cui->fields = dllist_append(cui->fields, (dllist_t) cff);
 
     ptr = ptr->next;
   }
